@@ -150,13 +150,13 @@ class KubeModel(ABC):
         """
         job_id = self.args._job_id
         func_id = self.args._func_id
-        self.logger.debug('saving file to host')
+        self.logger.debug('saving test file to host')
 
         with open(f'/output/{job_id}:test:{func_id}.pkl', 'wb') as f:
-            self.logger.debug(f'saving file, epoch: {self.epoch}')
+            self.logger.debug(f'saving test file to path: /output/{job_id}:test:{func_id}.pkl , epoch: {self.epoch}')
             pickle.dump('test', f)
-            self.logger.debug('file saved')
-        print('file saved')   
+            self.logger.debug('test file saved')
+        print('test file saved')   
 
     def _load_file_test(self):
         """
@@ -166,9 +166,9 @@ class KubeModel(ABC):
         job_id = self.args._job_id
         func_id = self.args._func_id
         if os.path.isfile(f'/output/{job_id}:test:{func_id}.pkl'):
-            self.logger.debug('loading file from host')
+            self.logger.debug(f'loading test file from host, path: /output/{job_id}:test:{func_id}.pkl')
             with open(f'/output/{job_id}:test:{func_id}.pkl', 'rb') as f:
-                self.logger.debug(f'loading file, epoch: {self.epoch}')
+                self.logger.debug(f'loading test file, epoch: {self.epoch}')
                 state = pickle.load(f)
                 self.logger.debug(f'file loaded, value: {state}')
                 print('file loaded')    
@@ -327,7 +327,7 @@ class KubeModel(ABC):
         self.__load_model()
         self._load_optimizer_redis()
         self._load_redis_test()
-        self._load_file_test()
+        #self._load_file_test()
 
         #self._load_optimizer_state()
 
